==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Snap/SnapCoordinatePolar/ts/SnapCoordinatePolar_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>SnapCoordinatePolar</name>
    <message>
        <location filename="../SnapCoordinatePolar.ui" line="+17"/>
        <source>&amp;r:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">r:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Radius (Distance)</source>
        <translatorcomment>--ignored case--
--file: qcadguiqt_pl.ts--
Promień (odległość)</translatorcomment>
        <translation type="unfinished">Promień (odległość)</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>&amp;&lt;:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">&amp;lt;:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Angle</source>
        <translatorcomment>--exact match--
--file: designer_pl.ts--
Wprowadź kąt:
Wprowadź kąt
Wskaż położenie linii wymiarowej:</translatorcomment>
        <translation type="unfinished">Kąt</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Tick for Relative Coordinate</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Zaznacz na współrzędne względne</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Relati&amp;ve</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Względny</translation>
    </message>
    <message>
        <location filename="../SnapCoordinatePolarInit.js" line="+2"/>
        <source>&amp;Polar Coordinate</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Polar współrzędnych</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Snap/SnapCoordinatePolar/ts/SnapCoordinatePolar_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>SnapCoordinatePolar</name>
    <message>
        <location filename="../SnapCoordinatePolar.ui" line="+17"/>
        <source>&amp;r:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>&amp;r:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Radius (Distance)</source>
        <translatorcomment>--ignored case--
--file: qcadguiqt_pl.ts--
Promień (odległość)</translatorcomment>
        <translation>Promień (odległość)</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>&amp;&lt;:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>&amp;&lt;:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Angle</source>
        <translatorcomment>--exact match--
--file: designer_pl.ts--
Wprowadź kąt:
Wprowadź kąt
Wskaż położenie linii wymiarowej:</translatorcomment>
        <translation>Kąt</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Tick for Relative Coordinate</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Używa współrzędnych względnych</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Relati&amp;ve</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>&amp;Względna</translation>
    </message>
    <message>
        <location filename="../SnapCoordinatePolarInit.js" line="+2"/>
        <source>&amp;Polar Coordinate</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Współrzędna &amp;biegunowa</translation>
    </message>
</context>
</TS>
